Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the transaction v1alpha1 API group +kubebuilder:object:generate=true +groupName=transaction.mesh-shaped.top
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "transaction.mesh-shaped.top", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Buyer ¶
type Buyer struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec BuyerSpec `json:"spec,omitempty"`
Status BuyerStatus `json:"status,omitempty"`
}
Buyer is the Schema for the buyers API
func (*Buyer) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Buyer.
func (*Buyer) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Buyer) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BuyerList ¶
type BuyerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Buyer `json:"items"`
}
BuyerList contains a list of Buyer
func (*BuyerList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuyerList.
func (*BuyerList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BuyerList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type BuyerSpec ¶
type BuyerSpec struct {
Name string `json:"name"`
Amount *int32 `json:"amount"`
Price string `json:"price"`
}
BuyerSpec defines the desired state of Buyer
func (*BuyerSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuyerSpec.
func (*BuyerSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type BuyerStatus ¶
type BuyerStatus struct {
}
BuyerStatus defines the observed state of Buyer
func (*BuyerStatus) DeepCopy ¶
func (in *BuyerStatus) DeepCopy() *BuyerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BuyerStatus.
func (*BuyerStatus) DeepCopyInto ¶
func (in *BuyerStatus) DeepCopyInto(out *BuyerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Seller ¶
type Seller struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec SellerSpec `json:"spec,omitempty"`
Status SellerStatus `json:"status,omitempty"`
}
Seller is the Schema for the sellers API
func (*Seller) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Seller.
func (*Seller) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Seller) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SellerList ¶
type SellerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Seller `json:"items"`
}
SellerList contains a list of Seller
func (*SellerList) DeepCopy ¶
func (in *SellerList) DeepCopy() *SellerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SellerList.
func (*SellerList) DeepCopyInto ¶
func (in *SellerList) DeepCopyInto(out *SellerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SellerList) DeepCopyObject ¶
func (in *SellerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SellerSpec ¶
type SellerSpec struct {
Name string `json:"name"`
Amount *int32 `json:"amount"`
Price string `json:"price"`
Money string `json:"money"`
}
SellerSpec defines the desired state of Seller
func (*SellerSpec) DeepCopy ¶
func (in *SellerSpec) DeepCopy() *SellerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SellerSpec.
func (*SellerSpec) DeepCopyInto ¶
func (in *SellerSpec) DeepCopyInto(out *SellerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SellerStatus ¶
type SellerStatus struct {
}
SellerStatus defines the observed state of Seller
func (*SellerStatus) DeepCopy ¶
func (in *SellerStatus) DeepCopy() *SellerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SellerStatus.
func (*SellerStatus) DeepCopyInto ¶
func (in *SellerStatus) DeepCopyInto(out *SellerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.